/*!
 *  \file    main_images_small.c
 *  \author  Wim Dolman (<a href="mailto:w.e.dolman@hva.nl">w.e.dolman@hva.nl</a>)
 *  \date    23-02-2020
 *  \version 2.1
 *
 *  \brief   Example: show eight 30K pictures on the display
 *           The original png-pictures are converted to c with a dedicated
 *           program png2c_ucg
 */

#define  F_CPU   32000000UL

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include <stdlib.h>

#include "../clock.h"
#include "../csrc/ucg.h"
#include "../ucglib_xmega_hal.h"

#include "leeuwinnen_small/donk_danielle_van_de.h"
#include "leeuwinnen_small/gragt_stephanie_van_der.h"
#include "leeuwinnen_small/groenen_jackie.h"
#include "leeuwinnen_small/miedema_vivianne.h"
#include "leeuwinnen_small/sanden_shanice_van_de.h"
#include "leeuwinnen_small/spitse_sherida.h"
#include "leeuwinnen_small/beerensteyn_lineth.h"
#include "leeuwinnen_small/veenendaal_sari_van.h"

ucg_t ucg;

int main(void)
{
  init_clock();
             
  ucg_Init(&ucg, ucg_dev_st7735_18x128x160, ucg_ext_st7735_18,
           (int (*)(struct _ucg_t *, int,  unsigned int,  unsigned char *)) ucg_comm_xmega);
  ucg_ClearScreen(&ucg);

  ucg_SetColor(&ucg, 0, 255, 255, 255);
  ucg_SetFontMode(&ucg, UCG_FONT_MODE_SOLID);
  ucg_SetFont(&ucg, ucg_font_8x13_mr);
  
  while (1) {
    ucg_image_spitse_sherida(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, "     Spitse    ");
    _delay_ms(500);

    ucg_image_donk_danielle_van_de(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, "  van de Donk  ");
    _delay_ms(500);

    ucg_image_miedema_vivianne(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, "    Miedema    ");
    _delay_ms(500);

    ucg_image_sanden_shanice_van_de(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, " van de Sanden ");
    _delay_ms(500);

    ucg_image_beerensteyn_lineth(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, "  Beerensteyn  ");
    _delay_ms(500);

    ucg_image_groenen_jackie(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, "    Groenen    ");
    _delay_ms(500);

    ucg_image_gragt_stephanie_van_der(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, "  van der Gragt ");
    _delay_ms(500);

    ucg_image_veenendaal_sari_van(&ucg, 18, 10);
    ucg_DrawString(&ucg, 0, 145, 0, " van Veenendaal ");
    _delay_ms(500);
  }
}

